# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/features_operator/v2/features_operator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.features_operator.v2 import features_operator_pb2 as qwak_dot_features__operator_dot_v2_dot_features__operator__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__pb2
from _qwak_proto.qwak.feature_store.sources import data_source_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9qwak/features_operator/v2/features_operator_service.proto\x12\x19qwak.features_operator.v2\x1a\x31qwak/features_operator/v2/features_operator.proto\x1a-qwak/feature_store/features/feature_set.proto\x1a,qwak/feature_store/sources/data_source.proto\"\x88\x01\n\x19ValidateDataSourceRequest\x12\x44\n\x10\x64\x61ta_source_spec\x18\x01 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\x12\x13\n\x0bnum_samples\x18\x02 \x01(\x05\x12\x10\n\x08zip_path\x18\x03 \x01(\t\"\x89\x01\n\x19ValidateFeatureSetRequest\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12\x10\n\x08zip_path\x18\x02 \x01(\t\x12\x13\n\x0bnum_samples\x18\x03 \x01(\x05\"\xc0\x01\n\x12ValidationResponse\x12P\n\x10success_response\x18\x01 \x01(\x0b\x32\x34.qwak.features_operator.v2.ValidationSuccessResponseH\x00\x12P\n\x10\x66\x61ilure_response\x18\x02 \x01(\x0b\x32\x34.qwak.features_operator.v2.ValidationFailureResponseH\x00\x42\x06\n\x04type2\x8f\x02\n\x17\x46\x65\x61turesOperatorService\x12y\n\x12ValidateDataSource\x12\x34.qwak.features_operator.v2.ValidateDataSourceRequest\x1a-.qwak.features_operator.v2.ValidationResponse\x12y\n\x12ValidateFeatureSet\x12\x34.qwak.features_operator.v2.ValidateFeatureSetRequest\x1a-.qwak.features_operator.v2.ValidationResponseB(\n$com.qwak.ai.features.operator.api.v2P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.features_operator.v2.features_operator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.features.operator.api.v2P\001'
  _globals['_VALIDATEDATASOURCEREQUEST']._serialized_start=233
  _globals['_VALIDATEDATASOURCEREQUEST']._serialized_end=369
  _globals['_VALIDATEFEATURESETREQUEST']._serialized_start=372
  _globals['_VALIDATEFEATURESETREQUEST']._serialized_end=509
  _globals['_VALIDATIONRESPONSE']._serialized_start=512
  _globals['_VALIDATIONRESPONSE']._serialized_end=704
  _globals['_FEATURESOPERATORSERVICE']._serialized_start=707
  _globals['_FEATURESOPERATORSERVICE']._serialized_end=978
# @@protoc_insertion_point(module_scope)
