"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.admiral.secret.v0.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SetSystemSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.admiral.secret.v0.secret_pb2.SetSystemEnvironmentSecretOptions: ...
    def __init__(
        self,
        *,
        options: qwak.admiral.secret.v0.secret_pb2.SetSystemEnvironmentSecretOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___SetSystemSecretRequest = SetSystemSecretRequest

class SetSystemSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetSystemSecretResponse = SetSystemSecretResponse

class DeleteSystemSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier:
        """Secret identifier"""
    def __init__(
        self,
        *,
        identifier: qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___DeleteSystemSecretRequest = DeleteSystemSecretRequest

class DeleteSystemSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteSystemSecretResponse = DeleteSystemSecretResponse

class GetSystemSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier:
        """Secret identifier"""
    def __init__(
        self,
        *,
        identifier: qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___GetSystemSecretRequest = GetSystemSecretRequest

class GetSystemSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def secret_definition(self) -> qwak.admiral.secret.v0.secret_pb2.SystemSecretDefinition:
        """Secret definition"""
    def __init__(
        self,
        *,
        secret_definition: qwak.admiral.secret.v0.secret_pb2.SystemSecretDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["secret_definition", b"secret_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_definition", b"secret_definition"]) -> None: ...

global___GetSystemSecretResponse = GetSystemSecretResponse
