# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/trigger.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.automation.v1 import common_pb2 as qwak_dot_automation_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/automation/v1/trigger.proto\x12\x12qwak.automation.v1\x1a\x1fqwak/automation/v1/common.proto\"\x9e\x02\n\x07Trigger\x12\x41\n\x11scheduled_trigger\x18\x01 \x01(\x0b\x32$.qwak.automation.v1.ScheduledTriggerH\x00\x12\x46\n\x14metric_based_trigger\x18\x02 \x01(\x0b\x32&.qwak.automation.v1.MetricBasedTriggerH\x00\x12\x37\n\x0cnone_trigger\x18\x03 \x01(\x0b\x32\x1f.qwak.automation.v1.NoneTriggerH\x00\x12\x44\n\x13on_boarding_trigger\x18\x04 \x01(\x0b\x32%.qwak.automation.v1.OnBoardingTriggerH\x00\x42\t\n\x07trigger\"B\n\x10ScheduledTrigger\x12\x0e\n\x04\x63ron\x18\x01 \x01(\tH\x00\x12\x12\n\x08interval\x18\x02 \x01(\tH\x00\x42\n\n\x08schedule\"\xc3\x01\n\x12MetricBasedTrigger\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x06metric\x18\x02 \x01(\x0b\x32\x1a.qwak.automation.v1.Metric\x12I\n\x13threshold_direction\x18\x03 \x01(\x0e\x32,.qwak.automation.v1.MetricThresholdDirection\x12\x11\n\tthreshold\x18\x04 \x01(\t\x12\x15\n\roverride_cron\x18\x05 \x01(\t\"\r\n\x0bNoneTrigger\"\x13\n\x11OnBoardingTriggerB!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.trigger_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _globals['_TRIGGER']._serialized_start=90
  _globals['_TRIGGER']._serialized_end=376
  _globals['_SCHEDULEDTRIGGER']._serialized_start=378
  _globals['_SCHEDULEDTRIGGER']._serialized_end=444
  _globals['_METRICBASEDTRIGGER']._serialized_start=447
  _globals['_METRICBASEDTRIGGER']._serialized_end=642
  _globals['_NONETRIGGER']._serialized_start=644
  _globals['_NONETRIGGER']._serialized_end=657
  _globals['_ONBOARDINGTRIGGER']._serialized_start=659
  _globals['_ONBOARDINGTRIGGER']._serialized_end=678
# @@protoc_insertion_point(module_scope)
