# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/reports/report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'qwak/feature_store/reports/report.proto\x12\x17qwak.feature.store.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd4\x01\n\x18\x42\x61tchJobIngestionDetails\x12\x38\n\x14\x62\x61tch_execution_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1bingestion_window_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x19ingestion_window_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1e\n\x1cStreamingJobIngestionDetails\")\n\'StreamingAggregationJobIngestionDetails\"\xec\x04\n\tJobReport\x12T\n\x17\x62\x61tch_ingestion_details\x18\x01 \x01(\x0b\x32\x31.qwak.feature.store.jobs.BatchJobIngestionDetailsH\x00\x12\\\n\x1bstreaming_ingestion_details\x18\x02 \x01(\x0b\x32\x35.qwak.feature.store.jobs.StreamingJobIngestionDetailsH\x00\x12l\n streaming_aggr_ingestion_details\x18\x03 \x01(\x0b\x32@.qwak.feature.store.jobs.StreamingAggregationJobIngestionDetailsH\x00\x12\x1c\n\x14num_affected_records\x18\x04 \x01(\x03\x12\x32\n\x0erun_start_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0crun_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x65xecution_id\x18\x07 \x01(\x03\x12\x16\n\x0e\x65nvironment_id\x18\x08 \x01(\t\x12\x15\n\rfeatureset_id\x18\t \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\n \x01(\t\x12\x32\n\x06status\x18\x0b \x01(\x0e\x32\".qwak.feature.store.jobs.JobStatus\x12\x12\n\ntry_number\x18\x0c \x01(\x05\x42\x13\n\x11ingestion_details*m\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x16\n\x12JOB_STATUS_SUCCESS\x10\x01\x12\x16\n\x12JOB_STATUS_FAILURE\x10\x02\x12\x18\n\x14JOB_STATUS_TOO_EARLY\x10\x03\x42%\n!com.qwak.ai.feature.store.reportsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.reports.report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.feature.store.reportsP\001'
  _globals['_JOBSTATUS']._serialized_start=1014
  _globals['_JOBSTATUS']._serialized_end=1123
  _globals['_BATCHJOBINGESTIONDETAILS']._serialized_start=102
  _globals['_BATCHJOBINGESTIONDETAILS']._serialized_end=314
  _globals['_STREAMINGJOBINGESTIONDETAILS']._serialized_start=316
  _globals['_STREAMINGJOBINGESTIONDETAILS']._serialized_end=346
  _globals['_STREAMINGAGGREGATIONJOBINGESTIONDETAILS']._serialized_start=348
  _globals['_STREAMINGAGGREGATIONJOBINGESTIONDETAILS']._serialized_end=389
  _globals['_JOBREPORT']._serialized_start=392
  _globals['_JOBREPORT']._serialized_end=1012
# @@protoc_insertion_point(module_scope)
