# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/databricks/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKqwak/administration/runtime_configuration/v0/external/databricks/auth.proto\x12@qwak.administration.runtime_configuration.v0.external.databricks\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\x9f\x02\n\x0e\x44\x61tabricksAuth\x12r\n\x0f\x64\x62_access_token\x18\x01 \x01(\x0b\x32W.qwak.administration.runtime_configuration.v0.external.databricks.DatabricksAccessTokenH\x00\x12\x8b\x01\n\x18\x64\x62_principal_credentials\x18\x02 \x01(\x0b\x32g.qwak.administration.runtime_configuration.v0.external.databricks.DatabricksServicePrincipalCredentialsH\x00\x42\x0b\n\tauth_type\"\xb6\x01\n%DatabricksServicePrincipalCredentials\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12`\n\rclient_secret\x18\x02 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\x18\n\x16\x63lient_secret_location\"~\n\x15\x44\x61tabricksAccessToken\x12Y\n\x06secret\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\n\n\x08locationB\xef\x01\n9com.jfrog.ml.runtime_configuration.v0.external.databricksP\x01Z\xaf\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external/databricks;external_databricksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9com.jfrog.ml.runtime_configuration.v0.external.databricksP\001Z\257\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external/databricks;external_databricks'
  _globals['_DATABRICKSAUTH']._serialized_start=211
  _globals['_DATABRICKSAUTH']._serialized_end=498
  _globals['_DATABRICKSSERVICEPRINCIPALCREDENTIALS']._serialized_start=501
  _globals['_DATABRICKSSERVICEPRINCIPALCREDENTIALS']._serialized_end=683
  _globals['_DATABRICKSACCESSTOKEN']._serialized_start=685
  _globals['_DATABRICKSACCESSTOKEN']._serialized_end=811
# @@protoc_insertion_point(module_scope)
