# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/prompt/v1/prompt/prompt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.model_descriptor import open_ai_descriptor_pb2 as qwak_dot_model__descriptor_dot_open__ai__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/prompt/v1/prompt/prompt.proto\x12\x15qwak.prompt.v1.prompt\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.qwak/model_descriptor/open_ai_descriptor.proto\"\xdb\x01\n\x06Prompt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12R\n\x1a\x64\x65\x66\x61ult_version_definition\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.PromptVersionDefinition\x12\x37\n\x08metadata\x18\x03 \x01(\x0b\x32%.qwak.prompt.v1.prompt.PromptMetadata\x12\x36\n\x0bprompt_spec\x18\x04 \x01(\x0b\x32!.qwak.prompt.v1.prompt.PromptSpec\"w\n\rPromptVersion\x12\x13\n\x0bprompt_name\x18\x01 \x01(\t\x12Q\n\x19prompt_version_definition\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.PromptVersionDefinition\"\xb9\x01\n\x17PromptVersionDefinition\x12\x16\n\x0eversion_number\x18\x01 \x01(\x05\x12>\n\x0cversion_spec\x18\x02 \x01(\x0b\x32(.qwak.prompt.v1.prompt.PromptVersionSpec\x12\x46\n\x10version_metadata\x18\x03 \x01(\x0b\x32,.qwak.prompt.v1.prompt.PromptVersionMetadata\"^\n\x0bPromptBrief\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x0eversion_briefs\x18\x02 \x03(\x0b\x32).qwak.prompt.v1.prompt.PromptVersionBrief\"\x98\x01\n\x12PromptVersionBrief\x12\x16\n\x0eversion_number\x18\x01 \x01(\x05\x12I\n\x14model_provider_brief\x18\x02 \x01(\x0b\x32).qwak.prompt.v1.prompt.ModelProviderBriefH\x00\x42\x1f\n\x1doptional_model_provider_brief\"8\n\x12ModelProviderBrief\x12\"\n\x1amodel_provider_case_number\x18\x01 \x01(\x05\"!\n\nPromptSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\"\xcf\x01\n\x11PromptVersionSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12>\n\x0fprompt_template\x18\x02 \x01(\x0b\x32%.qwak.prompt.v1.prompt.PromptTemplate\x12H\n\x10model_descriptor\x18\x03 \x01(\x0b\x32,.qwak.prompt.v1.prompt.PromptModelDescriptorH\x00\x42\x1b\n\x19optional_model_descriptor\"c\n\x0ePromptTemplate\x12I\n\x14\x63hat_prompt_template\x18\x01 \x01(\x0b\x32).qwak.prompt.v1.prompt.ChatPromptTemplateH\x00\x42\x06\n\x04type\"O\n\x12\x43hatPromptTemplate\x12\x39\n\rchat_messages\x18\x01 \x03(\x0b\x32\".qwak.prompt.v1.prompt.ChatMessage\"\x83\x01\n\x0b\x43hatMessage\x12\x36\n\x04role\x18\x01 \x01(\x0b\x32(.qwak.prompt.v1.prompt.PromptMessageRole\x12<\n\x08template\x18\x02 \x01(\x0b\x32*.qwak.prompt.v1.prompt.ChatMessageTemplate\"[\n\x13\x43hatMessageTemplate\x12<\n\rtext_template\x18\x01 \x01(\x0b\x32#.qwak.prompt.v1.prompt.TextTemplateH\x00\x42\x06\n\x04type\" \n\x0cTextTemplate\x12\x10\n\x08template\x18\x01 \x01(\t\"\xe6\x01\n\x11PromptMessageRole\x12\x43\n\nhuman_role\x18\x01 \x01(\x0b\x32-.qwak.prompt.v1.prompt.HumanPromptMessageRoleH\x00\x12\x45\n\x0bsystem_role\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.SystemPromptMessageRoleH\x00\x12=\n\x07\x61i_role\x18\x03 \x01(\x0b\x32*.qwak.prompt.v1.prompt.AIPromptMessageRoleH\x00\x42\x06\n\x04role\"\x18\n\x16HumanPromptMessageRole\"\x19\n\x17SystemPromptMessageRole\"\x15\n\x13\x41IPromptMessageRole\"r\n\x15PromptModelDescriptor\x12G\n\x10open_ai_provider\x18\x01 \x01(\x0b\x32+.qwak.prompt.v1.prompt.PromptOpenAIProviderH\x00\x42\x10\n\x0emodel_provider\"t\n\x14PromptOpenAIProvider\x12\\\n\x18open_ai_model_descriptor\x18\x01 \x01(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIModelDescriptor\"T\n\x0ePromptMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\"[\n\x15PromptVersionMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\tB$\n com.qwak.ai.prompt.api.v1.promptP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.prompt.v1.prompt.prompt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.qwak.ai.prompt.api.v1.promptP\001'
  _globals['_PROMPT']._serialized_start=143
  _globals['_PROMPT']._serialized_end=362
  _globals['_PROMPTVERSION']._serialized_start=364
  _globals['_PROMPTVERSION']._serialized_end=483
  _globals['_PROMPTVERSIONDEFINITION']._serialized_start=486
  _globals['_PROMPTVERSIONDEFINITION']._serialized_end=671
  _globals['_PROMPTBRIEF']._serialized_start=673
  _globals['_PROMPTBRIEF']._serialized_end=767
  _globals['_PROMPTVERSIONBRIEF']._serialized_start=770
  _globals['_PROMPTVERSIONBRIEF']._serialized_end=922
  _globals['_MODELPROVIDERBRIEF']._serialized_start=924
  _globals['_MODELPROVIDERBRIEF']._serialized_end=980
  _globals['_PROMPTSPEC']._serialized_start=982
  _globals['_PROMPTSPEC']._serialized_end=1015
  _globals['_PROMPTVERSIONSPEC']._serialized_start=1018
  _globals['_PROMPTVERSIONSPEC']._serialized_end=1225
  _globals['_PROMPTTEMPLATE']._serialized_start=1227
  _globals['_PROMPTTEMPLATE']._serialized_end=1326
  _globals['_CHATPROMPTTEMPLATE']._serialized_start=1328
  _globals['_CHATPROMPTTEMPLATE']._serialized_end=1407
  _globals['_CHATMESSAGE']._serialized_start=1410
  _globals['_CHATMESSAGE']._serialized_end=1541
  _globals['_CHATMESSAGETEMPLATE']._serialized_start=1543
  _globals['_CHATMESSAGETEMPLATE']._serialized_end=1634
  _globals['_TEXTTEMPLATE']._serialized_start=1636
  _globals['_TEXTTEMPLATE']._serialized_end=1668
  _globals['_PROMPTMESSAGEROLE']._serialized_start=1671
  _globals['_PROMPTMESSAGEROLE']._serialized_end=1901
  _globals['_HUMANPROMPTMESSAGEROLE']._serialized_start=1903
  _globals['_HUMANPROMPTMESSAGEROLE']._serialized_end=1927
  _globals['_SYSTEMPROMPTMESSAGEROLE']._serialized_start=1929
  _globals['_SYSTEMPROMPTMESSAGEROLE']._serialized_end=1954
  _globals['_AIPROMPTMESSAGEROLE']._serialized_start=1956
  _globals['_AIPROMPTMESSAGEROLE']._serialized_end=1977
  _globals['_PROMPTMODELDESCRIPTOR']._serialized_start=1979
  _globals['_PROMPTMODELDESCRIPTOR']._serialized_end=2093
  _globals['_PROMPTOPENAIPROVIDER']._serialized_start=2095
  _globals['_PROMPTOPENAIPROVIDER']._serialized_end=2211
  _globals['_PROMPTMETADATA']._serialized_start=2213
  _globals['_PROMPTMETADATA']._serialized_end=2297
  _globals['_PROMPTVERSIONMETADATA']._serialized_start=2299
  _globals['_PROMPTVERSIONMETADATA']._serialized_end=2390
# @@protoc_insertion_point(module_scope)
