"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UserSecretSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """Base64 encoded Value of the secret"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___UserSecretSpec = UserSecretSpec

class SystemSecretSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> global___SystemSecretValue:
        """The Value of The Secret"""
    def __init__(
        self,
        *,
        value: global___SystemSecretValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___SystemSecretSpec = SystemSecretSpec

class SystemSecretDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret identifier"""
    @property
    def spec(self) -> global___SystemSecretSpec:
        """Secret Spec"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        spec: global___SystemSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> None: ...

global___SystemSecretDefinition = SystemSecretDefinition

class EnvironmentSecretIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the secret"""
    environment_id: builtins.str
    """Environment of secret"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "name", b"name"]) -> None: ...

global___EnvironmentSecretIdentifier = EnvironmentSecretIdentifier

class SetUserEnvironmentSecretOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret identifier"""
    @property
    def spec(self) -> global___UserSecretSpec:
        """Secret Spec"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        spec: global___UserSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> None: ...

global___SetUserEnvironmentSecretOptions = SetUserEnvironmentSecretOptions

class SetSystemEnvironmentSecretOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret identifier"""
    @property
    def spec(self) -> global___SystemSecretSpec:
        """Secret Spec"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        spec: global___SystemSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> None: ...

global___SetSystemEnvironmentSecretOptions = SetSystemEnvironmentSecretOptions

class SystemSecretValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPAQUE_FIELD_NUMBER: builtins.int
    DOCKER_CONFIG_JSON_FIELD_NUMBER: builtins.int
    OPAQUE_PAIR_FIELD_NUMBER: builtins.int
    opaque: builtins.str
    """Base64 encoded value"""
    @property
    def docker_config_json(self) -> google.protobuf.struct_pb2.Struct:
        """Serialized ~/.docker/config.json file"""
    @property
    def opaque_pair(self) -> global___OpaquePairValue:
        """map of pairs arbitrary user-defined data"""
    def __init__(
        self,
        *,
        opaque: builtins.str = ...,
        docker_config_json: google.protobuf.struct_pb2.Struct | None = ...,
        opaque_pair: global___OpaquePairValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["docker_config_json", b"docker_config_json", "opaque", b"opaque", "opaque_pair", b"opaque_pair", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker_config_json", b"docker_config_json", "opaque", b"opaque", "opaque_pair", b"opaque_pair", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value", b"value"]) -> typing_extensions.Literal["opaque", "docker_config_json", "opaque_pair"] | None: ...

global___SystemSecretValue = SystemSecretValue

class OpaquePairValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class PairsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PAIRS_FIELD_NUMBER: builtins.int
    @property
    def pairs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """key and Base64 encoded value"""
    def __init__(
        self,
        *,
        pairs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pairs", b"pairs"]) -> None: ...

global___OpaquePairValue = OpaquePairValue

class AccountSecrets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRETS_FIELD_NUMBER: builtins.int
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentSecretMetadata]:
        """Environment secrets"""
    def __init__(
        self,
        *,
        secrets: collections.abc.Iterable[global___EnvironmentSecretMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secrets", b"secrets"]) -> None: ...

global___AccountSecrets = AccountSecrets

class EnvironmentSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_UPDATED_AT_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret Identifier"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Created at datetime"""
    @property
    def last_updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last updated at datetime"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "identifier", b"identifier", "last_updated_at", b"last_updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "identifier", b"identifier", "last_updated_at", b"last_updated_at"]) -> None: ...

global___EnvironmentSecretMetadata = EnvironmentSecretMetadata
