"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.account.v1.personalization_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountPreferences(google.protobuf.message.Message):
    """An account preferences"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERSONALIZATION_FIELD_NUMBER: builtins.int
    @property
    def personalization(self) -> qwak.administration.account.v1.personalization_pb2.AccountPersonalization:
        """Account personalization"""
    def __init__(
        self,
        *,
        personalization: qwak.administration.account.v1.personalization_pb2.AccountPersonalization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["personalization", b"personalization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["personalization", b"personalization"]) -> None: ...

global___AccountPreferences = AccountPreferences
