# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/builds_orchestrator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2
from _qwak_proto.qwak.builds import build_url_pb2 as qwak_dot_builds_dot_build__url__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/builds/builds_orchestrator_service.proto\x12\x18qwak.builds.orchestrator\x1a\x17qwak/builds/build.proto\x1a\x1bqwak/builds/build_url.proto\"R\n\x11\x42uildModelRequest\x12=\n\nbuild_spec\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.RemoteBuildSpec\"\x14\n\x12\x42uildModelResponse\"+\n\x17\x43\x61ncelBuildModelRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelBuildModelResponse\"*\n\x16\x43reateUploadURLRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"C\n\x17\x43reateUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\"h\n\"GetBuildVersioningUploadURLRequest\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"i\n#GetBuildVersioningUploadUrlsRequest\x12\x42\n\x06params\x18\x01 \x03(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"\xa7\x02\n#GetBuildVersioningUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12Q\n\x15\x61uthentication_detail\x18\x03 \x01(\x0b\x32..qwak.builds.orchestrator.AuthenticationDetailB\x02\x18\x01\x12[\n\x07headers\x18\x04 \x03(\x0b\x32J.qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x14\x41uthenticationDetail\x12Z\n\x1bjfrog_authentication_detail\x18\x01 \x01(\x0b\x32\x33.qwak.builds.orchestrator.JfrogAuthenticationDetailH\x00\x42\x12\n\x10integration_type\"\xf4\x01\n$GetBuildVersioningUploadUrlsResponse\x12l\n\x10upload_url_infos\x18\x01 \x03(\x0b\x32R.qwak.builds.orchestrator.GetBuildVersioningUploadUrlsResponse.UploadUrlInfosEntry\x1a^\n\x13UploadUrlInfosEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.qwak.builds.orchestrator.UploadUrlInfo:\x02\x38\x01\"\xa8\x01\n\rUploadUrlInfo\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x45\n\x07headers\x18\x03 \x03(\x0b\x32\x34.qwak.builds.orchestrator.UploadUrlInfo.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x19JfrogAuthenticationDetail\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"j\n$GetBuildVersioningDownloadURLRequest\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"k\n%GetBuildVersioningDownloadUrLsRequest\x12\x42\n\x06params\x18\x01 \x03(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"\xdf\x01\n%GetBuildVersioningDownloadURLResponse\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\x12]\n\x07headers\x18\x03 \x03(\x0b\x32L.qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x02\n&GetBuildVersioningDownloadUrlsResponse\x12r\n\x12\x64ownload_url_infos\x18\x01 \x03(\x0b\x32V.qwak.builds.orchestrator.GetBuildVersioningDownloadUrlsResponse.DownloadUrlInfosEntry\x1a\x62\n\x15\x44ownloadUrlInfosEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.builds.orchestrator.DownloadUrlInfo:\x02\x38\x01\"\xb3\x01\n\x0f\x44ownloadUrlInfo\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\x12G\n\x07headers\x18\x03 \x03(\x0b\x32\x36.qwak.builds.orchestrator.DownloadUrlInfo.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x1eListBuildVersioningTagsRequest\x12L\n\x15\x62uild_versioning_tags\x18\x01 \x01(\x0b\x32-.qwak.builds.orchestrator.BuildVersioningTags\"\x9c\x01\n\x1fListBuildVersioningTagsResponse\x12\x61\n build_versioning_tags_properties\x18\x01 \x03(\x0b\x32\x37.qwak.builds.orchestrator.BuildVersioningTagsProperties\x12\x16\n\x0eui_direct_link\x18\x02 \x01(\t\"\x95\x01\n\x16\x43reateDataTableRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12<\n\x05table\x18\x04 \x01(\x0b\x32-.qwak.builds.orchestrator.DataTableDefinition\x12\x0c\n\x04path\x18\x05 \x01(\t\"\x19\n\x17\x43reateDataTableResponse\"n\n\x1dGetBaseDockerImageNameRequest\x12M\n\x16\x62\x61se_docker_image_type\x18\x01 \x01(\x0e\x32-.qwak.builds.orchestrator.BaseDockerImageType\"@\n\x1eGetBaseDockerImageNameResponse\x12\x1e\n\x16\x62\x61se_docker_image_name\x18\x01 \x01(\t\"f\n\x17SaveArtifactPathRequest\x12K\n\x12\x61rtifact_path_spec\x18\x01 \x01(\x0b\x32/.qwak.builds.orchestrator.BuildArtifactPathSpec\"\x1a\n\x18SaveArtifactPathResponse\"-\n\x19ListBuildArtifactsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"X\n\x1aListBuildArtifactsResponse\x12:\n\tartifacts\x18\x01 \x03(\x0b\x32\'.qwak.builds.orchestrator.BuildArtifact\"A\n$DetachBuildsFromModelVersionsRequest\x12\x19\n\x11model_version_ids\x18\x01 \x03(\t\"\'\n%DetachBuildsFromModelVersionsResponse2\xb8\x0e\n\x19\x42uildsOrchestratorService\x12g\n\nBuildModel\x12+.qwak.builds.orchestrator.BuildModelRequest\x1a,.qwak.builds.orchestrator.BuildModelResponse\x12y\n\x10\x43\x61ncelBuildModel\x12\x31.qwak.builds.orchestrator.CancelBuildModelRequest\x1a\x32.qwak.builds.orchestrator.CancelBuildModelResponse\x12{\n\x0f\x43reateUploadURL\x12\x30.qwak.builds.orchestrator.CreateUploadURLRequest\x1a\x31.qwak.builds.orchestrator.CreateUploadURLResponse\"\x03\x88\x02\x01\x12\x9a\x01\n\x1bGetBuildVersioningUploadURL\x12<.qwak.builds.orchestrator.GetBuildVersioningUploadURLRequest\x1a=.qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse\x12\x9d\x01\n\x1cGetBuildVersioningUploadUrls\x12=.qwak.builds.orchestrator.GetBuildVersioningUploadUrlsRequest\x1a>.qwak.builds.orchestrator.GetBuildVersioningUploadUrlsResponse\x12\xa0\x01\n\x1dGetBuildVersioningDownloadURL\x12>.qwak.builds.orchestrator.GetBuildVersioningDownloadURLRequest\x1a?.qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse\x12\xa3\x01\n\x1eGetBuildVersioningDownloadUrls\x12?.qwak.builds.orchestrator.GetBuildVersioningDownloadUrLsRequest\x1a@.qwak.builds.orchestrator.GetBuildVersioningDownloadUrlsResponse\x12\x8e\x01\n\x17ListBuildVersioningTags\x12\x38.qwak.builds.orchestrator.ListBuildVersioningTagsRequest\x1a\x39.qwak.builds.orchestrator.ListBuildVersioningTagsResponse\x12v\n\x0f\x43reateDataTable\x12\x30.qwak.builds.orchestrator.CreateDataTableRequest\x1a\x31.qwak.builds.orchestrator.CreateDataTableResponse\x12\x8b\x01\n\x16GetBaseDockerImageName\x12\x37.qwak.builds.orchestrator.GetBaseDockerImageNameRequest\x1a\x38.qwak.builds.orchestrator.GetBaseDockerImageNameResponse\x12y\n\x10SaveArtifactPath\x12\x31.qwak.builds.orchestrator.SaveArtifactPathRequest\x1a\x32.qwak.builds.orchestrator.SaveArtifactPathResponse\x12\x7f\n\x12ListBuildArtifacts\x12\x33.qwak.builds.orchestrator.ListBuildArtifactsRequest\x1a\x34.qwak.builds.orchestrator.ListBuildArtifactsResponse\x12\xa0\x01\n\x1d\x44\x65tachBuildsFromModelVersions\x12>.qwak.builds.orchestrator.DetachBuildsFromModelVersionsRequest\x1a?.qwak.builds.orchestrator.DetachBuildsFromModelVersionsResponseB\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.builds_orchestrator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._options = None
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGUPLOADURLRESPONSE.fields_by_name['authentication_detail']._options = None
  _GETBUILDVERSIONINGUPLOADURLRESPONSE.fields_by_name['authentication_detail']._serialized_options = b'\030\001'
  _GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY._options = None
  _GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY._serialized_options = b'8\001'
  _UPLOADURLINFO_HEADERSENTRY._options = None
  _UPLOADURLINFO_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._options = None
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY._options = None
  _GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY._serialized_options = b'8\001'
  _DOWNLOADURLINFO_HEADERSENTRY._options = None
  _DOWNLOADURLINFO_HEADERSENTRY._serialized_options = b'8\001'
  _BUILDSORCHESTRATORSERVICE.methods_by_name['CreateUploadURL']._options = None
  _BUILDSORCHESTRATORSERVICE.methods_by_name['CreateUploadURL']._serialized_options = b'\210\002\001'
  _globals['_BUILDMODELREQUEST']._serialized_start=129
  _globals['_BUILDMODELREQUEST']._serialized_end=211
  _globals['_BUILDMODELRESPONSE']._serialized_start=213
  _globals['_BUILDMODELRESPONSE']._serialized_end=233
  _globals['_CANCELBUILDMODELREQUEST']._serialized_start=235
  _globals['_CANCELBUILDMODELREQUEST']._serialized_end=278
  _globals['_CANCELBUILDMODELRESPONSE']._serialized_start=280
  _globals['_CANCELBUILDMODELRESPONSE']._serialized_end=306
  _globals['_CREATEUPLOADURLREQUEST']._serialized_start=308
  _globals['_CREATEUPLOADURLREQUEST']._serialized_end=350
  _globals['_CREATEUPLOADURLRESPONSE']._serialized_start=352
  _globals['_CREATEUPLOADURLRESPONSE']._serialized_end=419
  _globals['_GETBUILDVERSIONINGUPLOADURLREQUEST']._serialized_start=421
  _globals['_GETBUILDVERSIONINGUPLOADURLREQUEST']._serialized_end=525
  _globals['_GETBUILDVERSIONINGUPLOADURLSREQUEST']._serialized_start=527
  _globals['_GETBUILDVERSIONINGUPLOADURLSREQUEST']._serialized_end=632
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE']._serialized_start=635
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE']._serialized_end=930
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY']._serialized_start=884
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY']._serialized_end=930
  _globals['_AUTHENTICATIONDETAIL']._serialized_start=933
  _globals['_AUTHENTICATIONDETAIL']._serialized_end=1067
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE']._serialized_start=1070
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE']._serialized_end=1314
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY']._serialized_start=1220
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY']._serialized_end=1314
  _globals['_UPLOADURLINFO']._serialized_start=1317
  _globals['_UPLOADURLINFO']._serialized_end=1485
  _globals['_UPLOADURLINFO_HEADERSENTRY']._serialized_start=884
  _globals['_UPLOADURLINFO_HEADERSENTRY']._serialized_end=930
  _globals['_JFROGAUTHENTICATIONDETAIL']._serialized_start=1487
  _globals['_JFROGAUTHENTICATIONDETAIL']._serialized_end=1547
  _globals['_GETBUILDVERSIONINGDOWNLOADURLREQUEST']._serialized_start=1549
  _globals['_GETBUILDVERSIONINGDOWNLOADURLREQUEST']._serialized_end=1655
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSREQUEST']._serialized_start=1657
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSREQUEST']._serialized_end=1764
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE']._serialized_start=1767
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE']._serialized_end=1990
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY']._serialized_start=884
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY']._serialized_end=930
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE']._serialized_start=1993
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE']._serialized_end=2249
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY']._serialized_start=2151
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY']._serialized_end=2249
  _globals['_DOWNLOADURLINFO']._serialized_start=2252
  _globals['_DOWNLOADURLINFO']._serialized_end=2431
  _globals['_DOWNLOADURLINFO_HEADERSENTRY']._serialized_start=884
  _globals['_DOWNLOADURLINFO_HEADERSENTRY']._serialized_end=930
  _globals['_LISTBUILDVERSIONINGTAGSREQUEST']._serialized_start=2433
  _globals['_LISTBUILDVERSIONINGTAGSREQUEST']._serialized_end=2543
  _globals['_LISTBUILDVERSIONINGTAGSRESPONSE']._serialized_start=2546
  _globals['_LISTBUILDVERSIONINGTAGSRESPONSE']._serialized_end=2702
  _globals['_CREATEDATATABLEREQUEST']._serialized_start=2705
  _globals['_CREATEDATATABLEREQUEST']._serialized_end=2854
  _globals['_CREATEDATATABLERESPONSE']._serialized_start=2856
  _globals['_CREATEDATATABLERESPONSE']._serialized_end=2881
  _globals['_GETBASEDOCKERIMAGENAMEREQUEST']._serialized_start=2883
  _globals['_GETBASEDOCKERIMAGENAMEREQUEST']._serialized_end=2993
  _globals['_GETBASEDOCKERIMAGENAMERESPONSE']._serialized_start=2995
  _globals['_GETBASEDOCKERIMAGENAMERESPONSE']._serialized_end=3059
  _globals['_SAVEARTIFACTPATHREQUEST']._serialized_start=3061
  _globals['_SAVEARTIFACTPATHREQUEST']._serialized_end=3163
  _globals['_SAVEARTIFACTPATHRESPONSE']._serialized_start=3165
  _globals['_SAVEARTIFACTPATHRESPONSE']._serialized_end=3191
  _globals['_LISTBUILDARTIFACTSREQUEST']._serialized_start=3193
  _globals['_LISTBUILDARTIFACTSREQUEST']._serialized_end=3238
  _globals['_LISTBUILDARTIFACTSRESPONSE']._serialized_start=3240
  _globals['_LISTBUILDARTIFACTSRESPONSE']._serialized_end=3328
  _globals['_DETACHBUILDSFROMMODELVERSIONSREQUEST']._serialized_start=3330
  _globals['_DETACHBUILDSFROMMODELVERSIONSREQUEST']._serialized_end=3395
  _globals['_DETACHBUILDSFROMMODELVERSIONSRESPONSE']._serialized_start=3397
  _globals['_DETACHBUILDSFROMMODELVERSIONSRESPONSE']._serialized_end=3436
  _globals['_BUILDSORCHESTRATORSERVICE']._serialized_start=3439
  _globals['_BUILDSORCHESTRATORSERVICE']._serialized_end=5287
# @@protoc_insertion_point(module_scope)
