# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.execution.v1 import execution_service_pb2 as qwak_dot_execution_dot_v1_dot_execution__service__pb2


class FeatureStoreExecutionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TriggerBatchBackfill = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchBackfill',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillResponse.FromString,
                )
        self.TriggerBatchFeatureset = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchFeatureset',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetResponse.FromString,
                )
        self.TriggerOnlineStreamingIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOnlineStreamingIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionResponse.FromString,
                )
        self.TriggerOfflineStreamingIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOfflineStreamingIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionResponse.FromString,
                )
        self.TriggerRowLevelStreamingAggregationIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerRowLevelStreamingAggregationIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionResponse.FromString,
                )
        self.TriggerCompactionStreamingAggregationIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerCompactionStreamingAggregationIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionResponse.FromString,
                )
        self.TriggerStreamingAggregationBackfill = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerStreamingAggregationBackfill',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillResponse.FromString,
                )
        self.TriggerFeaturesetDeletion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerFeaturesetDeletion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionResponse.FromString,
                )
        self.GetExecutionStatus = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionStatus',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusResponse.FromString,
                )
        self.GetExecutionEntry = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionEntry',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryResponse.FromString,
                )
        self.GetRunningExecutionEntries = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetRunningExecutionEntries',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesResponse.FromString,
                )
        self.InitPaginationByFeaturesetId = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/InitPaginationByFeaturesetId',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdResponse.FromString,
                )
        self.ListExecutionsByFeaturesetId = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListExecutionsByFeaturesetId',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdResponse.FromString,
                )
        self.ListLastExecutionsForEnvironment = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListLastExecutionsForEnvironment',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentResponse.FromString,
                )


class FeatureStoreExecutionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TriggerBatchBackfill(self, request, context):
        """Batch Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerBatchFeatureset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOnlineStreamingIngestion(self, request, context):
        """Streaming Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOfflineStreamingIngestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerRowLevelStreamingAggregationIngestion(self, request, context):
        """Streaming Aggregation Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerCompactionStreamingAggregationIngestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerStreamingAggregationBackfill(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerFeaturesetDeletion(self, request, context):
        """Deletion
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionStatus(self, request, context):
        """Listings/ Paginated Listings /Getters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionEntry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunningExecutionEntries(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitPaginationByFeaturesetId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExecutionsByFeaturesetId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLastExecutionsForEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureStoreExecutionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TriggerBatchBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerBatchBackfill,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillResponse.SerializeToString,
            ),
            'TriggerBatchFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerBatchFeatureset,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetResponse.SerializeToString,
            ),
            'TriggerOnlineStreamingIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOnlineStreamingIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionResponse.SerializeToString,
            ),
            'TriggerOfflineStreamingIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOfflineStreamingIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionResponse.SerializeToString,
            ),
            'TriggerRowLevelStreamingAggregationIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerRowLevelStreamingAggregationIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionResponse.SerializeToString,
            ),
            'TriggerCompactionStreamingAggregationIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerCompactionStreamingAggregationIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionResponse.SerializeToString,
            ),
            'TriggerStreamingAggregationBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerStreamingAggregationBackfill,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillResponse.SerializeToString,
            ),
            'TriggerFeaturesetDeletion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerFeaturesetDeletion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionResponse.SerializeToString,
            ),
            'GetExecutionStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecutionStatus,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusResponse.SerializeToString,
            ),
            'GetExecutionEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecutionEntry,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryResponse.SerializeToString,
            ),
            'GetRunningExecutionEntries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunningExecutionEntries,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesResponse.SerializeToString,
            ),
            'InitPaginationByFeaturesetId': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPaginationByFeaturesetId,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdResponse.SerializeToString,
            ),
            'ListExecutionsByFeaturesetId': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExecutionsByFeaturesetId,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdResponse.SerializeToString,
            ),
            'ListLastExecutionsForEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLastExecutionsForEnvironment,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.execution.v1.FeatureStoreExecutionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureStoreExecutionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TriggerBatchBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchBackfill',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerBatchFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchFeatureset',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOnlineStreamingIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOnlineStreamingIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOfflineStreamingIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOfflineStreamingIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerRowLevelStreamingAggregationIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerRowLevelStreamingAggregationIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerCompactionStreamingAggregationIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerCompactionStreamingAggregationIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerStreamingAggregationBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerStreamingAggregationBackfill',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerFeaturesetDeletion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerFeaturesetDeletion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecutionStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionStatus',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecutionEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionEntry',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunningExecutionEntries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetRunningExecutionEntries',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitPaginationByFeaturesetId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/InitPaginationByFeaturesetId',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExecutionsByFeaturesetId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListExecutionsByFeaturesetId',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLastExecutionsForEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListLastExecutionsForEnvironment',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
