"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValidationSuccessResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAMPLE_FIELD_NUMBER: builtins.int
    PANDAS_COLUMN_DESCRIPTION_FIELD_NUMBER: builtins.int
    SPARK_COLUMN_DESCRIPTION_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    sample: builtins.str
    """The sample of the success response"""
    @property
    def pandas_column_description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PandasColumnDescription]:
        """The pandas column description of the success response"""
    @property
    def spark_column_description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SparkColumnDescription]:
        """The spark column description of the success response"""
    @property
    def outputs(self) -> global___Outputs:
        """the outputs printed during the run"""
    def __init__(
        self,
        *,
        sample: builtins.str = ...,
        pandas_column_description: collections.abc.Iterable[global___PandasColumnDescription] | None = ...,
        spark_column_description: collections.abc.Iterable[global___SparkColumnDescription] | None = ...,
        outputs: global___Outputs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["outputs", b"outputs", "pandas_column_description", b"pandas_column_description", "sample", b"sample", "spark_column_description", b"spark_column_description"]) -> None: ...

global___ValidationSuccessResponse = ValidationSuccessResponse

class PandasColumnDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    PANDAS_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """The column name"""
    pandas_type: builtins.str
    """The pandas type of the column"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        pandas_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "pandas_type", b"pandas_type"]) -> None: ...

global___PandasColumnDescription = PandasColumnDescription

class SparkColumnDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    SPARK_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """The column name"""
    spark_type: builtins.str
    """The spark type of the column"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        spark_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "spark_type", b"spark_type"]) -> None: ...

global___SparkColumnDescription = SparkColumnDescription

class ValidationFailureResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHASE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    phase: builtins.str
    """The phase in which the validation failed in"""
    error_message: builtins.str
    """The error message of the failure"""
    description: builtins.str
    """The error message description"""
    @property
    def outputs(self) -> global___Outputs:
        """the outputs printed during the run"""
    def __init__(
        self,
        *,
        phase: builtins.str = ...,
        error_message: builtins.str = ...,
        description: builtins.str = ...,
        outputs: global___Outputs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "error_message", b"error_message", "outputs", b"outputs", "phase", b"phase"]) -> None: ...

global___ValidationFailureResponse = ValidationFailureResponse

class Outputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STDOUT_FIELD_NUMBER: builtins.int
    STDERR_FIELD_NUMBER: builtins.int
    stdout: builtins.str
    """the stdout printed during the run"""
    stderr: builtins.str
    """the stderr printed during the run"""
    def __init__(
        self,
        *,
        stdout: builtins.str = ...,
        stderr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stderr", b"stderr", "stdout", b"stdout"]) -> None: ...

global___Outputs = Outputs

class ValidationNotReadyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ValidationNotReadyResponse = ValidationNotReadyResponse
